summaryrefslogtreecommitdiffstats
path: root/src/viewmpeg2.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /src/viewmpeg2.cpp
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/viewmpeg2.cpp')
-rw-r--r--src/viewmpeg2.cpp86
1 files changed, 43 insertions, 43 deletions
diff --git a/src/viewmpeg2.cpp b/src/viewmpeg2.cpp
index 66a966a..ae8c0f7 100644
--- a/src/viewmpeg2.cpp
+++ b/src/viewmpeg2.cpp
@@ -9,17 +9,17 @@
#include "viewmpeg2.h"
-#include <qvariant.h>
-#include <qpushbutton.h>
-#include <qframe.h>
-#include <qtoolbutton.h>
-#include <qslider.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
-#include <qimage.h>
-#include <qpixmap.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqframe.h>
+#include <tqtoolbutton.h>
+#include <tqslider.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
+#include <tqimage.h>
+#include <tqpixmap.h>
static const unsigned char img0_viewmpeg2[] = {
0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
@@ -125,13 +125,13 @@ static const unsigned char img2_viewmpeg2[] = {
/*
* Constructs a ViewMPEG2 as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-ViewMPEG2::ViewMPEG2( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+ViewMPEG2::ViewMPEG2( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
- QImage img;
+ TQImage img;
img.loadFromData( img0_viewmpeg2, sizeof( img0_viewmpeg2 ), "PNG" );
image0 = img;
img.loadFromData( img1_viewmpeg2, sizeof( img1_viewmpeg2 ), "PNG" );
@@ -140,51 +140,51 @@ ViewMPEG2::ViewMPEG2( QWidget* parent, const char* name, WFlags fl )
image2 = img;
if ( !name )
setName( "ViewMPEG2" );
- setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)7, 0, 0, sizePolicy().hasHeightForWidth() ) );
- setSizeIncrement( QSize( 0, 0 ) );
- setBaseSize( QSize( 0, 0 ) );
+ tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 0, sizePolicy().hasHeightForWidth() ) );
+ setSizeIncrement( TQSize( 0, 0 ) );
+ setBaseSize( TQSize( 0, 0 ) );
setIcon( image0 );
- ViewMPEG2Layout = new QGridLayout( this, 1, 1, 2, 6, "ViewMPEG2Layout");
+ ViewMPEG2Layout = new TQGridLayout( this, 1, 1, 2, 6, "ViewMPEG2Layout");
- frame7 = new QFrame( this, "frame7" );
- frame7->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, frame7->sizePolicy().hasHeightForWidth() ) );
- frame7->setMaximumSize( QSize( 32767, 50 ) );
- frame7->setFrameShape( QFrame::StyledPanel );
- frame7->setFrameShadow( QFrame::Raised );
- frame7Layout = new QGridLayout( frame7, 1, 1, 11, 6, "frame7Layout");
+ frame7 = new TQFrame( this, "frame7" );
+ frame7->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, frame7->sizePolicy().hasHeightForWidth() ) );
+ frame7->setMaximumSize( TQSize( 32767, 50 ) );
+ frame7->setFrameShape( TQFrame::StyledPanel );
+ frame7->setFrameShadow( TQFrame::Raised );
+ frame7Layout = new TQGridLayout( frame7, 1, 1, 11, 6, "frame7Layout");
- bStop = new QToolButton( frame7, "bStop" );
- bStop->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)1, 0, 0, bStop->sizePolicy().hasHeightForWidth() ) );
- bStop->setIconSet( QIconSet( image1 ) );
+ bStop = new TQToolButton( frame7, "bStop" );
+ bStop->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)1, 0, 0, bStop->sizePolicy().hasHeightForWidth() ) );
+ bStop->setIconSet( TQIconSet( image1 ) );
frame7Layout->addWidget( bStop, 0, 0 );
- bPlay = new QToolButton( frame7, "bPlay" );
- bPlay->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)1, 0, 0, bPlay->sizePolicy().hasHeightForWidth() ) );
- bPlay->setIconSet( QIconSet( image2 ) );
+ bPlay = new TQToolButton( frame7, "bPlay" );
+ bPlay->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)1, 0, 0, bPlay->sizePolicy().hasHeightForWidth() ) );
+ bPlay->setIconSet( TQIconSet( image2 ) );
frame7Layout->addWidget( bPlay, 0, 1 );
- slider = new QSlider( frame7, "slider" );
- slider->setOrientation( QSlider::Horizontal );
+ slider = new TQSlider( frame7, "slider" );
+ slider->setOrientation( Qt::Horizontal );
frame7Layout->addWidget( slider, 0, 2 );
ViewMPEG2Layout->addWidget( frame7, 1, 0 );
- label = new QLabel( this, "label" );
- label->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)2, (QSizePolicy::SizeType)2, 0, 0, label->sizePolicy().hasHeightForWidth() ) );
+ label = new TQLabel( this, "label" );
+ label->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)2, (TQSizePolicy::SizeType)2, 0, 0, label->sizePolicy().hasHeightForWidth() ) );
ViewMPEG2Layout->addWidget( label, 0, 0 );
languageChange();
- resize( QSize(320, 320).expandedTo(minimumSizeHint()) );
+ resize( TQSize(320, 320).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// signals and slots connections
- connect( bStop, SIGNAL( clicked() ), this, SLOT( bStopClick() ) );
- connect( bPlay, SIGNAL( clicked() ), this, SLOT( bPlayClick() ) );
- connect( slider, SIGNAL( sliderReleased() ), this, SLOT( sliderReleased() ) );
- connect( slider, SIGNAL( sliderPressed() ), this, SLOT( sliderPressed() ) );
+ connect( bStop, TQT_SIGNAL( clicked() ), this, TQT_SLOT( bStopClick() ) );
+ connect( bPlay, TQT_SIGNAL( clicked() ), this, TQT_SLOT( bPlayClick() ) );
+ connect( slider, TQT_SIGNAL( sliderReleased() ), this, TQT_SLOT( sliderReleased() ) );
+ connect( slider, TQT_SIGNAL( sliderPressed() ), this, TQT_SLOT( sliderPressed() ) );
}
/*
@@ -192,7 +192,7 @@ ViewMPEG2::ViewMPEG2( QWidget* parent, const char* name, WFlags fl )
*/
ViewMPEG2::~ViewMPEG2()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -202,8 +202,8 @@ ViewMPEG2::~ViewMPEG2()
void ViewMPEG2::languageChange()
{
setCaption( tr2i18n( "k9Copy - Title Preview" ) );
- bStop->setText( QString::null );
- bPlay->setText( QString::null );
+ bStop->setText( TQString() );
+ bPlay->setText( TQString() );
}
void ViewMPEG2::sliderReleased()
@@ -125,13 +125,13 @@ static const unsigned char img2_viewmpeg2[] = {
/*
- * Constructs a ViewMPEG2 as a child of 'parent', with the
+ * Constructs a ViewMPEG2 as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
@@ -192,7 +192,7 @@ ViewMPEG2::ViewMPEG2( QWidget* parent, const char* name, WFlags fl )
ViewMPEG2::~ViewMPEG2()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*